@@ -1,6 +1,8 @@
 import base64
 import getpass
 import os
+import sys
+import termios
 import traceback
 import requests
 from kubernetes import config
@@ -12,10 +14,11 @@ from .cred_cache import CredCache
 from .idp_session import IdpSession
 from .idp_login import IdpLogin
 from adam.config import Config
-from adam.utils import log, log2, log_to_file
+from adam.utils import log, log2
 
 class Idp:
     ctrl_c_entered = False
+    term_moded = False
 
     # the singleton pattern
     def __new__(cls, *args, **kwargs):
@@ -33,7 +36,11 @@ class Idp:
             token_server = Config().get('app.login.token-server-url', 'http://localhost:{port}').replace('{port}', port)
             res: requests.Response = requests.get(token_server)
             if res.status_code == 200 and res.text:
-                return session.login_from_token(res.text)
+                try:
+                    # may fail if the idp token is not complete
+                    return session.login_from_token(res.text)
+                except:
+                    pass
 
         r: IdpLogin = None
         try:
@@ -69,54 +76,25 @@ class Idp:
                 log()
                 log(f'{session.idp_host()} login: {username}')
 
-            def gp(default_pass: str = None):
-                password = getpass.getpass(f'Password(default ********): ')
-                if default_pass and not password:
-                    return default_pass
-
-                while len(password) == 1024:
-                    frag = getpass.getpass('')
-                    log2(f'frag: {frag}')
-                    password = password + frag
-
-                return password
-
             password = None
             while password == None or Idp.ctrl_c_entered: # exit the while loop even if password is empty string
                 if Idp.ctrl_c_entered:
                     Idp.ctrl_c_entered = False
+                Idp.set_term_no_limit()
 
                 default_pass = CredCache().get_password() if use_cached_creds else None
                 if default_pass:
                     if forced:
                         password = default_pass
                     else:
-                        password = gp(default_pass=default_pass)
-                        # password = getpass.getpass(f'Password(default ********): ') or default_pass
+                        password = getpass.getpass(f'Password(default ********): ') or default_pass
                 else:
-                    password = gp()
-                    # password = getpass.getpass(f'Password: ')
+                    password = getpass.getpass(f'Password: ')
 
             if username and password:
-                try:
-                    log2(password)
-                    kubeconfig_string = base64.b64decode(password.encode('ascii') + b'==').decode('utf-8')
-                    if kubeconfig_string.startswith('apiVersion: '):
-                        kubeconfig_dict = yaml.safe_load(kubeconfig_string)
-                        config.kube_config.load_kube_config_from_dict(kubeconfig_dict)
-                        log2('Kubectl file loaded')
-                        log_to_file(kubeconfig_dict)
-                        # Secrets.list_secrets(os.getenv('NAMESPACE'))
-
-                        # if listing secrets does not fail, the kubeconfig string is good
-                        log2('Accepted kubeconfig file as password.')
-                        r = IdpLogin(None, None, None, username)
-                        log(f"You're signed in as {username}")
-
-                        return r
-                except:
-                    log2(traceback.format_exc())
-                    pass
+                if r := Idp.try_kubeconfig(username, password):
+                    log(f"You're signed in as {username}")
+                    return r
 
                 r = session.authenticator.authenticate(session.idp_uri, app_host, username, password)
                 if r:
@@ -129,4 +107,30 @@ class Idp:
             elif username and Config().get('app.login.cache-username', True):
                 CredCache().cache(username)
 
+        return None
+
+    def set_term_no_limit():
+        if not Idp.term_moded:
+            # override 4096 character limit with OS terminal
+            fd = sys.stdin.fileno()
+            new = termios.tcgetattr(fd)
+            new[3] = new[3] & ~termios.ICANON
+            termios.tcsetattr(fd, termios.TCSADRAIN, new)
+
+            Idp.term_moded = True
+
+    def try_kubeconfig(username: str, kubeconfig: str):
+        try:
+            kubeconfig_string = base64.b64decode(kubeconfig.encode('ascii') + b'==').decode('utf-8')
+            if kubeconfig_string.startswith('apiVersion: '):
+                kubeconfig_dict = yaml.safe_load(kubeconfig_string)
+                config.kube_config.load_kube_config_from_dict(kubeconfig_dict)
+                # test if you can list Kubernetes secretes with the given kubeconfig file
+                Secrets.list_secrets(os.getenv('NAMESPACE'))
+
+                return IdpLogin(None, None, None, username)
+        except:
+            Config().debug(traceback.format_exc())
+            pass
+
         return None
\ No newline at end of file
